==> blesta-5.10.2.zip: blesta/language/de_de/logs.php <==
<?php
/**
 * Logs
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Logs.!error.end_date.format'] = 'Ungültiges Enddatum-Format.';
$lang['Logs.!error.start_date.format'] = 'Ungültiges Format für das Startdatum.';
$lang['Logs.!error.group.betweenlength'] = 'Die Gruppe muss zwischen 1 und 32 Zeichen lang sein.';
$lang['Logs.!error.group.unique'] = 'Die ID und die Gruppe der Cron-Aufgabe sind bereits vergeben.';
$lang['Logs.!error.event.maxlength'] = 'Die Länge des Ereignisses darf 32 Zeichen nicht überschreiten.';
$lang['Logs.!error.run_id.exists'] = 'Ungültige Cron-Task-ID.';
$lang['Logs.!error.last_name.empty'] = 'Der Nachname darf nicht leer sein.';
$lang['Logs.!error.first_name.empty'] = 'Der Vorname darf nicht leer sein.';
$lang['Logs.!error.account_id.empty'] = 'Fehlende Konto-ID.';
$lang['Logs.!error.account_type.format'] = 'Ungültiger Kontotyp.';
$lang['Logs.!error.type.format'] = 'Ungültiger Typ.';
$lang['Logs.!error.staff_id.empty'] = 'Fehlender Personalausweis.';
$lang['Logs.!error.date_changed.valid'] = 'Ungültiges Datum geändert.';
$lang['Logs.!error.by_user_id.exists'] = 'Ungültig nach Benutzer-ID.';
$lang['Logs.!error.fields.empty'] = 'Fehlende protokollierbare Felder.';
$lang['Logs.!error.client_id.exists'] = 'Ungültige Client-ID.';
$lang['Logs.!error.contact_id.empty'] = 'Fehlende Kontakt-ID.';
$lang['Logs.!error.success.format'] = 'Ungültiger Erfolgswert.';
$lang['Logs.!error.messenger_id.exists'] = 'Ungültige Messenger-ID.';
$lang['Logs.!error.to_user_id.exists'] = 'Ungültige Benutzer-ID.';
$lang['Logs.!error.result.format'] = 'Das Ergebnis der Anmeldung muss entweder "Erfolg" oder "Misserfolg" sein.';
$lang['Logs.!error.user_log_exists.empty'] = 'Der Benutzer mit der angegebenen IP-Adresse existiert nicht.';
$lang['Logs.!error.ip_address.length'] = 'Die IP-Adresse darf maximal 39 Zeichen lang sein.';
$lang['Logs.!error.ip_address.empty'] = 'Fehlende IP-Adresse.';
$lang['Logs.!error.user_id.empty'] = 'Fehlende Benutzer-ID.';
$lang['Logs.!error.group.maxlength'] = 'Die Gruppenlänge darf 8 Zeichen nicht überschreiten.';
$lang['Logs.!error.group.empty'] = 'Fehlende Gruppe.';
$lang['Logs.!error.status.format'] = 'Ungültige Statusart.';
$lang['Logs.!error.url.empty'] = 'Fehlende URL.';
$lang['Logs.!error.direction.format'] = 'Ungültiger Richtungstyp.';
$lang['Logs.!error.gateway_id.exists'] = 'Ungültige Gateway-ID.';
$lang['Logs.!error.module_id.exists'] = 'Ungültige Modul-ID.';
$lang['Logs.!error.staff_id.exists'] = 'Ungültige Personal-ID.';
$lang['Logs.!error.sent.length'] = 'Die gesendete Länge darf 1 Zeichen nicht überschreiten.';
$lang['Logs.!error.sent.format'] = 'Gesendet muss eine Zahl sein.';
$lang['Logs.!error.subject.empty'] = 'Es fehlt ein Thema.';
$lang['Logs.!error.from_name.empty'] = 'Es fehlt ein von-Name.';
$lang['Logs.!error.from_address.empty'] = 'Es fehlt eine Absenderadresse.';
$lang['Logs.!error.to_address.empty'] = 'Es fehlt ein zu adressieren.';
$lang['Logs.!error.company_id.exists'] = 'Ungültige Unternehmens-ID.';
$lang['Logs.!error.deletelog_datetime'] = 'Ungültiges Datumsformat.';

==> blesta-5.11.4.zip: blesta/language/de_de/logs.php <==
<?php
/**
 * Logs
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Logs.!error.end_date.format'] = 'Ungültiges Enddatum-Format.';
$lang['Logs.!error.start_date.format'] = 'Ungültiges Format für das Startdatum.';
$lang['Logs.!error.group.betweenlength'] = 'Die Gruppe muss zwischen 1 und 32 Zeichen lang sein.';
$lang['Logs.!error.group.unique'] = 'Die ID und die Gruppe der Cron-Aufgabe sind bereits vergeben.';
$lang['Logs.!error.event.maxlength'] = 'Die Länge des Ereignisses darf 32 Zeichen nicht überschreiten.';
$lang['Logs.!error.run_id.exists'] = 'Ungültige Cron-Task-ID.';
$lang['Logs.!error.last_name.empty'] = 'Der Nachname darf nicht leer sein.';
$lang['Logs.!error.first_name.empty'] = 'Der Vorname darf nicht leer sein.';
$lang['Logs.!error.account_id.empty'] = 'Fehlende Konto-ID.';
$lang['Logs.!error.account_type.format'] = 'Ungültiger Kontotyp.';
$lang['Logs.!error.type.format'] = 'Ungültiger Typ.';
$lang['Logs.!error.staff_id.empty'] = 'Fehlender Personalausweis.';
$lang['Logs.!error.date_changed.valid'] = 'Ungültiges Datum geändert.';
$lang['Logs.!error.by_user_id.exists'] = 'Ungültig nach Benutzer-ID.';
$lang['Logs.!error.fields.empty'] = 'Fehlende protokollierbare Felder.';
$lang['Logs.!error.client_id.exists'] = 'Ungültige Client-ID.';
$lang['Logs.!error.contact_id.empty'] = 'Fehlende Kontakt-ID.';
$lang['Logs.!error.success.format'] = 'Ungültiger Erfolgswert.';
$lang['Logs.!error.messenger_id.exists'] = 'Ungültige Messenger-ID.';
$lang['Logs.!error.to_user_id.exists'] = 'Ungültige Benutzer-ID.';
$lang['Logs.!error.result.format'] = 'Das Ergebnis der Anmeldung muss entweder "Erfolg" oder "Misserfolg" sein.';
$lang['Logs.!error.user_log_exists.empty'] = 'Der Benutzer mit der angegebenen IP-Adresse existiert nicht.';
$lang['Logs.!error.ip_address.length'] = 'Die IP-Adresse darf maximal 39 Zeichen lang sein.';
$lang['Logs.!error.ip_address.empty'] = 'Fehlende IP-Adresse.';
$lang['Logs.!error.user_id.empty'] = 'Fehlende Benutzer-ID.';
$lang['Logs.!error.group.maxlength'] = 'Die Gruppenlänge darf 8 Zeichen nicht überschreiten.';
$lang['Logs.!error.group.empty'] = 'Fehlende Gruppe.';
$lang['Logs.!error.status.format'] = 'Ungültige Statusart.';
$lang['Logs.!error.url.empty'] = 'Fehlende URL.';
$lang['Logs.!error.direction.format'] = 'Ungültiger Richtungstyp.';
$lang['Logs.!error.gateway_id.exists'] = 'Ungültige Gateway-ID.';
$lang['Logs.!error.module_id.exists'] = 'Ungültige Modul-ID.';
$lang['Logs.!error.staff_id.exists'] = 'Ungültige Personal-ID.';
$lang['Logs.!error.sent.length'] = 'Die gesendete Länge darf 1 Zeichen nicht überschreiten.';
$lang['Logs.!error.sent.format'] = 'Gesendet muss eine Zahl sein.';
$lang['Logs.!error.subject.empty'] = 'Es fehlt ein Thema.';
$lang['Logs.!error.from_name.empty'] = 'Es fehlt ein von-Name.';
$lang['Logs.!error.from_address.empty'] = 'Es fehlt eine Absenderadresse.';
$lang['Logs.!error.to_address.empty'] = 'Es fehlt ein zu adressieren.';
$lang['Logs.!error.company_id.exists'] = 'Ungültige Unternehmens-ID.';
$lang['Logs.!error.deletelog_datetime'] = 'Ungültiges Datumsformat.';
$lang['Logs.!error.new_service.format'] = 'Der neue Dienst muss ein Array sein.';
$lang['Logs.!error.old_service.format'] = 'Der alte Dienst muss ein Array sein.';
$lang['Logs.!error.transactions.exists'] = 'Eine oder mehrere Transaktionen sind nicht vorhanden.';
$lang['Logs.!error.transaction_id.format'] = 'Transaktionen müssen ein Array sein.';
$lang['Logs.!error.service_id.exists'] = 'Ungültige Dienst-ID.';
